@@ -3,6 +3,10 @@ Minion data cache plugin for Consul key/value data store.
 
 .. versionadded:: 2016.11.2
 
+.. versionchanged:: 3005.0
+
+    Timestamp/cache updated support added.
+
 :depends: python-consul >= 0.2.0
 
 It is up to the system administrator to set up and configure the Consul
@@ -30,6 +34,12 @@ could be set in the master config. These are the defaults:
     consul.consistency: default
     consul.dc: dc1
     consul.verify: True
+    consul.timestamp_suffix: .tstamp  # Added in 3005.0
+
+In order to bring the cache APIs into conformity, in 3005.0 timestamp
+information gets stored as a separate ``{key}.tstamp`` key/value. If your
+existing functionality depends on being able to store normal keys with the
+``.tstamp`` suffix, override the ``consul.timestamp_suffix`` default config.
 
 Related docs could be found in the `python-consul documentation`_.
 
@@ -47,6 +57,7 @@ value to ``consul``:
 """
 
 import logging
+import time
 
 import salt.payload
 from salt.exceptions import SaltCacheError
@@ -61,6 +72,7 @@ except ImportError:
 
 log = logging.getLogger(__name__)
 api = None
+_tstamp_suffix = ".tstamp"
 
 
 # Define the module's virtual name
@@ -90,7 +102,8 @@ def __virtual__():
     }
 
     try:
-        global api
+        global api, _tstamp_suffix
+        _tstamp_suffix = __opts__.get("consul.timestamp_suffix", _tstamp_suffix)
         api = consul.Consul(**consul_kwargs)
     except AttributeError:
         return (
@@ -107,9 +120,12 @@ def store(bank, key, data):
     Store a key value.
     """
     c_key = "{}/{}".format(bank, key)
+    tstamp_key = "{}/{}{}".format(bank, key, _tstamp_suffix)
+
     try:
         c_data = salt.payload.dumps(data)
         api.kv.put(c_key, c_data)
+        api.kv.put(tstamp_key, salt.payload.dumps(int(time.time())))
     except Exception as exc:  # pylint: disable=broad-except
         raise SaltCacheError(
             "There was an error writing the key, {}: {}".format(c_key, exc)
@@ -138,9 +154,13 @@ def flush(bank, key=None):
     """
     if key is None:
         c_key = bank
+        tstamp_key = None
     else:
         c_key = "{}/{}".format(bank, key)
+        tstamp_key = "{}/{}{}".format(bank, key, _tstamp_suffix)
     try:
+        if tstamp_key:
+            api.kv.delete(tstamp_key)
         return api.kv.delete(c_key, recurse=key is None)
     except Exception as exc:  # pylint: disable=broad-except
         raise SaltCacheError(
@@ -166,7 +186,7 @@ def list_(bank):
         out = set()
         for key in keys:
             out.add(key[len(bank) + 1 :].rstrip("/"))
-        keys = list(out)
+        keys = [o for o in out if not o.endswith(_tstamp_suffix)]
     return keys
 
 
@@ -174,14 +194,28 @@ def contains(bank, key):
     """
     Checks if the specified bank contains the specified key.
     """
-    if key is None:
-        return True  # any key could be a branch and a leaf at the same time in Consul
-    else:
-        try:
-            c_key = "{}/{}".format(bank, key)
-            _, value = api.kv.get(c_key)
-        except Exception as exc:  # pylint: disable=broad-except
-            raise SaltCacheError(
-                "There was an error getting the key, {}: {}".format(c_key, exc)
-            )
-        return value is not None
+    try:
+        c_key = "{}/{}".format(bank, key or "")
+        _, value = api.kv.get(c_key, keys=True)
+    except Exception as exc:  # pylint: disable=broad-except
+        raise SaltCacheError(
+            "There was an error getting the key, {}: {}".format(c_key, exc)
+        )
+    return value is not None
+
+
+def updated(bank, key):
+    """
+    Return the Unix Epoch timestamp of when the key was last updated. Return
+    None if key is not found.
+    """
+    c_key = "{}/{}{}".format(bank, key, _tstamp_suffix)
+    try:
+        _, value = api.kv.get(c_key)
+        if value is None:
+            return None
+        return salt.payload.loads(value["Value"])
+    except Exception as exc:  # pylint: disable=broad-except
+        raise SaltCacheError(
+            "There was an error reading the key, {}: {}".format(c_key, exc)
+        )
